@@ -1,17 +1,21 @@
-import asyncio
 import logging
 import time
-from fastapi import FastAPI, Response, Header, Request, Response
+from fastapi import FastAPI, Request
 from fastapi.responses import JSONResponse, PlainTextResponse
 from starlette.exceptions import HTTPException as StarletteHTTPException
 from fastapi.encoders import jsonable_encoder
 from fastapi.middleware.cors import CORSMiddleware
 import prometheus_client as pc
+import uuid
 
-c = pc.Counter('nbapi_request_count', 'Count the total number of incoming request', [
-               'path', 'status_code'])
-g = pc.Gauge('nbapi_request_duration',
-             'Gauge the duration of incoming request', ['path', 'status_code'])
+c = pc.Counter('nbapi_request_count', 'Count the total number of incoming request', ['path', 'status_code', 'cid'])
+g = pc.Gauge('nbapi_request_duration', 'Gauge the duration of incoming request', ['path', 'status_code', 'cid'])
+
+KEY_ID: str = 'id'
+KEY_INPUT: str = 'input'
+KEY_AUTH: str = 'auth'
+KEY_CID: str = 'cid'
+KEY_OUTPUT: str = 'output'
 
 
 class AuthError(Exception):
@@ -32,10 +36,12 @@ class NBApi(FastAPI):
 
         async def http_middleware(request: Request, call_next):
             ts = time.time()
+            request.state.KEY_ID = str(uuid.uuid4())
+            request.state.KEY_CID = 'unknown'
+            request.state.KEY_AUTH = request.headers['authorization']
             resp = await call_next(request)
-            c.labels(path=request.url.path, status_code=resp.status_code).inc()
-            g.labels(path=request.url.path, status_code=resp.status_code).set(
-                time.time() - ts)
+            c.labels(path=request.url.path, status_code=resp.status_code, cid=request.state.KEY_CID).inc()
+            g.labels(path=request.url.path, status_code=resp.status_code, cid=request.state.KEY_CID).set(time.time() - ts)
             return resp
 
         self.middleware('http')(http_middleware)
@@ -49,8 +55,7 @@ class NBApi(FastAPI):
             logging.error(exc)
             return JSONResponse(
                 status_code=exc.status_code,
-                content=jsonable_encoder(
-                    {'status': 'failed', 'code': f'{exc.status_code}'}),
+                content=jsonable_encoder({'status': 'failed', 'code': f'{exc.status_code}'}),
             )
         self.exception_handler(StarletteHTTPException)(handle_httperror)
 
@@ -58,8 +63,7 @@ class NBApi(FastAPI):
             logging.error(exc)
             return JSONResponse(
                 status_code=401,
-                content=jsonable_encoder(
-                    {'status': 'failed', 'code': '401'}),
+                content=jsonable_encoder({'status': 'failed', 'code': '401'}),
             )
         self.exception_handler(AuthError)(auth_error)
 
@@ -67,8 +71,7 @@ class NBApi(FastAPI):
             logging.error(exc)
             return JSONResponse(
                 status_code=400,
-                content=jsonable_encoder(
-                    {'status': 'failed', 'code': '400'}),
+                content=jsonable_encoder({'status': 'failed', 'code': '400'}),
             )
         self.exception_handler(ValueError)(handle_valueerror)
 
@@ -76,7 +79,6 @@ class NBApi(FastAPI):
             logging.error(exc)
             return JSONResponse(
                 status_code=500,
-                content=jsonable_encoder(
-                    {'status': 'failed', 'code': '500', 'msg': f'{str(exc)}'}),
+                content=jsonable_encoder({'status': 'failed', 'code': '500', 'msg': f'{str(exc)}'}),
             )
         self.exception_handler(Exception)(handle_exception)
